@@ -2,5 +2,5 @@
 # autogen.sh - generates configure using the autotools
 # $Id: autogen.sh,v 1.1 2002/03/03 07:56:30 mhoenicka Exp $
 aclocal
-automake --add-missing
-autoconf
\ No newline at end of file
+automake --add-missing --force-missing --copy
+autoconf
