@@ -17,8 +17,7 @@
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   along with this program; if not, see <http://www.gnu.org/licenses/>
 
 ********************************/
 
@@ -1132,7 +1131,7 @@ else {
 				       "CONF" => "Proceedings _scope",
 				       "CTLG" => "Catalogue _scope",
 				       "DATA" => "_scope of File",
-				       "ELECT" => "Web Page _scope", 
+				       "ELEC" => "Web Page _scope", 
 				       "ICOMM" => array( "title" => "Email Subject",
 							 "default" => "Email _scope"), 
 				       "INPR" => array( "Full Title" => "Journal Name",
@@ -1540,7 +1539,8 @@ function  monthChooser($datetype,$month) {
                                                     foreach ($lines as $line) {
                                                         // Check the type of each line and extract the content
                                                             $test=substr($line,0,2);
-                                                            $content=htmlentities(substr($line,6));
+#                                                            $content=htmlentities(substr($line,6));
+                                                            $content=substr($line,6);
 
                                                         // Assign the form variables based on the value of the test variable
                                                             if ($test=="N2") {
@@ -1752,4 +1752,4 @@ function  monthChooser($datetype,$month) {
                                                             return $formfields;
 
 }
-?>
\ No newline at end of file
+?>
