@@ -13,8 +13,7 @@
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   along with this program; if not, see <http://www.gnu.org/licenses/>
 
   ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
 
@@ -30,11 +29,11 @@
 #include "strfncs.h"
 #include "linklist.h"
 #include "tokenize.h"
+#include "refdbd.h"
 #include "dbfncs.h"
 #include "risdb.h"
 #include "authorinfo.h"
 #include "connect.h" /* for get_status_msg() */
-#include "refdbd.h"
 #include "xmlhelper.h"
 
 /* some globals */
@@ -635,7 +634,7 @@ static char* add_analytic_db(struct renderinfo* ptr_rendinfo, int n_refdb_id, ch
       return NULL;
     }
       
-    if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+    if (sgml_entitize(&entitize_buf, n_ref_format) == NULL) {
       free((char*)item);
       free(entitize_buf);
       return NULL;
@@ -756,7 +755,7 @@ static char* add_monogr_db(struct renderinfo* ptr_rendinfo, int n_refdb_id, char
 	  return NULL;
 	}
     
-	if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+	if (sgml_entitize(&entitize_buf, n_ref_format) == NULL) {
 	  free(entitize_buf);
 	  return NULL;
 	}
@@ -792,7 +791,7 @@ static char* add_monogr_db(struct renderinfo* ptr_rendinfo, int n_refdb_id, char
       return NULL;
     }
 
-    if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+    if (sgml_entitize(&entitize_buf, n_ref_format) == NULL) {
       free((char*)item);
       free(entitize_buf);
       return NULL;
@@ -833,7 +832,7 @@ static char* add_monogr_db(struct renderinfo* ptr_rendinfo, int n_refdb_id, char
 	return NULL;
       }
 
-      if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+      if (sgml_entitize(&entitize_buf, n_ref_format) == NULL) {
 	free(entitize_buf);
 	return NULL;
       }
@@ -853,7 +852,7 @@ static char* add_monogr_db(struct renderinfo* ptr_rendinfo, int n_refdb_id, char
 	    return NULL;
 	  }
 
-	  if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  if (sgml_entitize(&entitize_buf, n_ref_format) == NULL) {
 	    free(entitize_buf);
 	    return NULL;
 	  }
@@ -875,18 +874,36 @@ static char* add_monogr_db(struct renderinfo* ptr_rendinfo, int n_refdb_id, char
     }
   }
 
-  /* volume */
-  if ((item = get_refdb_volume(ptr_rendinfo->dbires)) != NULL) {
+  /* volume/edition (VL) */
+  if ((item = get_refdb_volume(ptr_rendinfo->dbires)) != NULL
+      || (item = get_refdb_edition(ptr_rendinfo->dbires)) != NULL) {
+    char voledtag[10] = "volumenum";
+
     if ((entitize_buf = mstrdup((char*)item)) == NULL) {
       return NULL;
     }
 
-    if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+    if (sgml_entitize(&entitize_buf, n_ref_format) == NULL) {
       free(entitize_buf);
       return NULL;
     }
 
-    if (print_element_x(entitize_buf, ptr_chunk_buf, ptr_chunk_buf_len, "volumenum", NULL, NULL, NULL, NULL, ptr_indent, ptr_rendinfo->ptr_clrequest->namespace) == NULL) {
+    if (!strcmp(type, "ADVS")
+	| !strcmp(type, "ART")
+	| !strcmp(type, "CHAP")
+	| !strcmp(type, "BOOK")
+	| !strcmp(type, "CTLG")
+	| !strcmp(type, "COMP")
+	| !strcmp(type, "MAP")
+	| !strcmp(type, "MUSIC")
+	| !strcmp(type, "NEWS")
+	| !strcmp(type, "PAMP")
+	| !strcmp(type, "SER")) {
+      strncpy(voledtag, "edition", 7);
+      voledtag[7]='\0';
+    }
+
+    if (print_element_x(entitize_buf, ptr_chunk_buf, ptr_chunk_buf_len, voledtag, NULL, NULL, NULL, NULL, ptr_indent, ptr_rendinfo->ptr_clrequest->namespace) == NULL) {
       free(entitize_buf);
       LOG_PRINT(LOG_CRIT, get_status_msg(801));
       return NULL;
@@ -902,7 +919,7 @@ static char* add_monogr_db(struct renderinfo* ptr_rendinfo, int n_refdb_id, char
       return NULL;
     }
 
-    if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+    if (sgml_entitize(&entitize_buf, n_ref_format) == NULL) {
       free(entitize_buf);
       return NULL;
     }
@@ -926,7 +943,7 @@ static char* add_monogr_db(struct renderinfo* ptr_rendinfo, int n_refdb_id, char
       return NULL;
     }
 
-    if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+    if (sgml_entitize(&entitize_buf, n_ref_format) == NULL) {
       free(entitize_buf);
       return NULL;
     }
@@ -940,7 +957,7 @@ static char* add_monogr_db(struct renderinfo* ptr_rendinfo, int n_refdb_id, char
 	return NULL;
       }
 
-      if (sgml_entitize(&entitized_endpage, NULL) == NULL) {
+      if (sgml_entitize(&entitized_endpage, n_ref_format) == NULL) {
 	free(entitize_buf);
 	free(entitized_endpage);
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
@@ -1080,7 +1097,7 @@ static char* add_series_db(struct renderinfo* ptr_rendinfo, int n_refdb_id, char
       return NULL;
     }
 
-    if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+    if (sgml_entitize(&entitize_buf, n_ref_format) == NULL) {
       free((char*)item);
       free(entitize_buf);
       return NULL;
@@ -1145,7 +1162,7 @@ static char* add_notes_db(struct renderinfo* ptr_rendinfo, int n_refdb_id, char
       return NULL;
     }
 
-    if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+    if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
       free((char*)item);
       free(entitize_buf);
       return NULL;
@@ -1200,7 +1217,7 @@ static char* add_abstract_db(struct renderinfo* ptr_rendinfo, int n_refdb_id, ch
       return NULL;
     }
 
-    if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+    if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
       free((char*)item);
       free(entitize_buf);
       return NULL;
@@ -1269,7 +1286,7 @@ static char* add_biblioids_db(struct renderinfo* ptr_rendinfo, int n_refdb_id, c
 	return NULL;
       }
 
-      if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+      if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	free((char*)item);
 	free(entitize_buf);
 	return NULL;
@@ -1297,7 +1314,7 @@ static char* add_biblioids_db(struct renderinfo* ptr_rendinfo, int n_refdb_id, c
 	return NULL;
       }
 
-      if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+      if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	free((char*)item);
 	free(entitize_buf);
 	return NULL;
@@ -1375,7 +1392,7 @@ static char* add_author_db(struct renderinfo* ptr_rendinfo, struct AUTHOR_INFO*
       return NULL;
     }
     
-    if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+    if (sgml_entitize(&entitize_buf, n_ref_format) == NULL) {
       free(entitize_buf);
       return NULL;
     }
@@ -1425,7 +1442,7 @@ static char* add_author_db(struct renderinfo* ptr_rendinfo, struct AUTHOR_INFO*
 	return NULL;
       }
     
-      if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+      if (sgml_entitize(&entitize_buf, n_ref_format) == NULL) {
 	free(entitize_buf);
 	return NULL;
       }
@@ -1444,7 +1461,7 @@ static char* add_author_db(struct renderinfo* ptr_rendinfo, struct AUTHOR_INFO*
 	  return NULL;
 	}
 
-	if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+	if (sgml_entitize(&entitize_buf, n_ref_format) == NULL) {
 	  free(entitize_buf);
 	  return NULL;
 	}
@@ -1463,7 +1480,7 @@ static char* add_author_db(struct renderinfo* ptr_rendinfo, struct AUTHOR_INFO*
 	return NULL;
       }
 
-      if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+      if (sgml_entitize(&entitize_buf, n_ref_format) == NULL) {
 	free(entitize_buf);
 	return NULL;
       }
@@ -1481,7 +1498,7 @@ static char* add_author_db(struct renderinfo* ptr_rendinfo, struct AUTHOR_INFO*
 	return NULL;
       }
 
-      if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+      if (sgml_entitize(&entitize_buf, n_ref_format) == NULL) {
 	free(entitize_buf);
 	return NULL;
       }
