@@ -13,8 +13,7 @@
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   along with this program; if not, see <http://www.gnu.org/licenses/>
 
   ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
 
@@ -385,7 +384,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
       }
 
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -417,7 +416,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
   if (item != NULL) {
     nhave_booktitle++;
 
-    if (sgml_entitize((char**)&item, NULL) == NULL) {
+    if (sgml_entitize((char**)&item, ptr_rendinfo->ref_format) == NULL) {
       LOG_PRINT(LOG_CRIT, get_status_msg(801));
       return 801;
     }
@@ -463,7 +462,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
     }
 
     if ((entitize_buf = strdup(item)) != NULL
-	&& sgml_entitize(&entitize_buf, NULL) == NULL) {
+	&& sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
       LOG_PRINT(LOG_CRIT, get_status_msg(801));
       return 801;
     }
@@ -501,7 +500,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
     }
 
     if ((entitize_buf = strdup(item)) != NULL
-	&& sgml_entitize(&entitize_buf, NULL) == NULL) {
+	&& sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
       LOG_PRINT(LOG_CRIT, get_status_msg(801));
       return 801;
     }
@@ -539,7 +538,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
     }
 
     if ((entitize_buf = strdup(item)) != NULL
-	&& sgml_entitize(&entitize_buf, NULL) == NULL) {
+	&& sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
       LOG_PRINT(LOG_CRIT, get_status_msg(801));
       return 801;
     }
@@ -591,7 +590,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
     }
 
     if ((entitize_buf = strdup(item)) != NULL
-	&& sgml_entitize(&entitize_buf, NULL) == NULL) {
+	&& sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
       LOG_PRINT(LOG_CRIT, get_status_msg(801));
       return 801;
     }
@@ -622,7 +621,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
     }
 
     if ((entitize_buf = strdup(item)) != NULL
-	&& sgml_entitize(&entitize_buf, NULL) == NULL) {
+	&& sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
       LOG_PRINT(LOG_CRIT, get_status_msg(801));
       return 801;
     }
@@ -743,7 +742,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
      || strstr((ptr_rendinfo->ptr_biblio_info)->format_string, "ALL") != NULL) {
     item = get_refdb_abstract_copy(ptr_rendinfo->dbires);
     if (item != NULL) {
-      if (sgml_entitize((char**)&item, NULL) == NULL) {
+      if (sgml_entitize((char**)&item, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	free((char*)item);
 	return 801;
@@ -763,7 +762,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
      || strstr((ptr_rendinfo->ptr_biblio_info)->format_string, "ALL") != NULL) {
     item = get_refdb_address_copy(ptr_rendinfo->dbires);
     if (item != NULL) {
-      if (sgml_entitize((char**)&item, NULL) == NULL) {
+      if (sgml_entitize((char**)&item, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	free((char*)item);
 	return 801;
@@ -887,7 +886,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 	}
 
 	if ((entitize_buf = strdup(reprint.avail+5)) != NULL
-	    && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	    && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	  LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	  return 801;
 	}
@@ -961,7 +960,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 	  }
 
 	  if ((entitize_buf = strdup(reprint.avail)) != NULL
-	      && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	      && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	    LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	    return 801;
 	  }
@@ -1025,7 +1024,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1047,7 +1046,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1069,7 +1068,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1112,7 +1111,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
       rel_frequency = calculate_relative_frequency(frequency, refcount);
       
       if ((entitize_buf = strdup(item)) == NULL
-	  || sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  || sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1177,7 +1176,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1197,7 +1196,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
     
     if (item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1217,7 +1216,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1237,7 +1236,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1257,7 +1256,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1279,7 +1278,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item && *item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1296,7 +1295,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item && *item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1313,7 +1312,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item && *item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1330,7 +1329,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item && *item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1347,7 +1346,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item && *item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1364,7 +1363,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item && *item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1381,7 +1380,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item && *item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1398,7 +1397,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item && *item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1415,7 +1414,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item && *item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1432,7 +1431,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item && *item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1449,7 +1448,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item && *item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1466,7 +1465,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item && *item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1483,7 +1482,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item && *item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1500,7 +1499,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item && *item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1517,7 +1516,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item && *item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1534,7 +1533,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item && *item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1551,7 +1550,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item && *item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1568,7 +1567,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 
     if (item && *item) {
       if ((entitize_buf = strdup(item)) != NULL
-	  && sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  && sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	return 801;
       }
@@ -1587,6 +1586,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
   /* URL, L1-L4, DOI */
   if (strstr((ptr_rendinfo->ptr_biblio_info)->format_string, "UR") != NULL
       || strstr((ptr_rendinfo->ptr_biblio_info)->format_string, "DOI") != NULL
+      || strstr((ptr_rendinfo->ptr_biblio_info)->format_string, "LX") != NULL
       || strstr((ptr_rendinfo->ptr_biblio_info)->format_string, "ALL") != NULL) {
     int i;
     char *entitize_string;
@@ -1632,7 +1632,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
 	  return 801;
 	}
 
-	if (sgml_entitize(&entitize_string, NULL) == NULL) {
+	if (sgml_entitize(&entitize_string, ptr_rendinfo->ref_format) == NULL) {
 	  LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	  clean_request(dbires);
 	  free(entitize_string);
@@ -1690,7 +1690,7 @@ int render_html(struct renderinfo* ptr_rendinfo, int n_istemp) {
     item = get_notes_copy(ptr_rendinfo->dbires, ptr_rendinfo->username);
 
     if (item != NULL) {
-      if (sgml_entitize((char**)&item, NULL) == NULL) {
+      if (sgml_entitize((char**)&item, ptr_rendinfo->ref_format) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
 	free((char*)item);
 	return 801;
@@ -1977,7 +1977,7 @@ static int add_author_info_html(char** ptr_buffer, size_t* ptr_buffer_len, int t
     sprintf(buffer, "<span class='%s relfreq%d'>", (*(ainfo.role)) ? ainfo.role:"author", rel_frequency);
 
     if ((entitize_buf = strdup(ainfo.name)) == NULL
-	|| sgml_entitize(&entitize_buf, NULL) == NULL) {
+	|| sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
       LOG_PRINT(LOG_CRIT, get_status_msg(801));
       return 801;
     }
