@@ -13,8 +13,7 @@
   GNU General Public License for more details.
    
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  along with this program; if not, see <http://www.gnu.org/licenses/>
 
   ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
 
@@ -617,7 +616,7 @@ static char* add_authors_mods(char** ptr_buffer, size_t* ptr_buffer_len, dbi_con
 	return NULL;
       }
 
-      if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+      if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	clean_request(dbires);
 	free(entitize_buf);
 	free_authorinfo(ptr_ainfo);
@@ -641,7 +640,7 @@ static char* add_authors_mods(char** ptr_buffer, size_t* ptr_buffer_len, dbi_con
 	  return NULL;
 	}
 	  
-	if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+	if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	  free(entitize_buf);
 	  free_authorinfo(ptr_ainfo);
 	  return NULL;
@@ -673,7 +672,7 @@ static char* add_authors_mods(char** ptr_buffer, size_t* ptr_buffer_len, dbi_con
 	  return NULL;
 	}
       
-	if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+	if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	  free(entitize_buf);
 	  free_authorinfo(ptr_ainfo);
 	  return NULL;
@@ -726,7 +725,7 @@ static char* add_authors_mods(char** ptr_buffer, size_t* ptr_buffer_len, dbi_con
 	return NULL;
       }
       
-      if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+      if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	free(entitize_buf);
 	free_authorinfo(ptr_ainfo);
 	return NULL;
@@ -1118,7 +1117,7 @@ static char* add_partinfo_mods(char** ptr_buffer, size_t* ptr_buffer_len, dbi_co
 	full_link = add_root_to_link(item, ptr_rendinfo->pdfroot);
       }
       else {
-	full_link = item;
+	full_link = (char*)item;
       }
 
       if (i == 5) { /* render doi as identifier */
@@ -1135,7 +1134,7 @@ static char* add_partinfo_mods(char** ptr_buffer, size_t* ptr_buffer_len, dbi_co
 	  return NULL;
 	}
 
-	if (print_element_x(full_link, &buffer1, &buffer1_len, "url", "access", "raw object", NULL, NULL, ptr_indent, ptr_rendinfo->ptr_clrequest->namespace) == NULL) {
+	if (print_element_x((const char*)full_link, &buffer1, &buffer1_len, "url", "access", "raw object", NULL, NULL, ptr_indent, ptr_rendinfo->ptr_clrequest->namespace) == NULL) {
 	  clean_request(dbires);
 	  return NULL;
 	}
@@ -1152,7 +1151,7 @@ static char* add_partinfo_mods(char** ptr_buffer, size_t* ptr_buffer_len, dbi_co
 	  return NULL;
 	}
 
-	if (print_element_x(full_link, &buffer1, &buffer1_len, "note", "related", ulink_type, NULL, NULL, ptr_indent, ptr_rendinfo->ptr_clrequest->namespace) == NULL) {
+	if (print_element_x((const char*)full_link, &buffer1, &buffer1_len, "note", "related", ulink_type, NULL, NULL, ptr_indent, ptr_rendinfo->ptr_clrequest->namespace) == NULL) {
 	  clean_request(dbires);
 	  return NULL;
 	}
