@@ -13,8 +13,7 @@
   GNU General Public License for more details.
    
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  along with this program; if not, see <http://www.gnu.org/licenses/>
 
   ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
 
@@ -346,15 +345,18 @@ int render_risx(struct renderinfo* ptr_rendinfo) {
   
   item = NULL;
 
-  item = get_refdb_booktitle_copy(ptr_rendinfo->dbires);
+  /* booktitle is self-explanatory except for CONF where it translates to the conference title which belongs to pubinfo */
+  if (strcmp(type, "CONF")) {
+    item = get_refdb_booktitle_copy(ptr_rendinfo->dbires);
 
-  if (item != NULL) {
-    if (print_element_x(item, &buffer, &buffer_len, "title", "type", "full", NULL, NULL, &xindent, ptr_rendinfo->ptr_clrequest->namespace) == NULL) {
-      free(buffer);
+    if (item != NULL) {
+      if (print_element_x(item, &buffer, &buffer_len, "title", "type", "full", NULL, NULL, &xindent, ptr_rendinfo->ptr_clrequest->namespace) == NULL) {
+	free(buffer);
+	free((char*)item);
+	return 801;
+      }
       free((char*)item);
-      return 801;
     }
-    free((char*)item);
   }
 
   if (add_authors_risx(&buffer, &buffer_len, conn, 2, ptr_rendinfo, &nhave_buffer_data, &xindent, refcount) == NULL) {
@@ -677,7 +679,7 @@ static char* add_authors_risx(char** ptr_buffer, size_t* ptr_buffer_len, dbi_con
 	return NULL;
       }
 
-      if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+      if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	clean_request(dbires);
 	free(entitize_buf);
 	free_authorinfo(ptr_ainfo);
@@ -701,7 +703,7 @@ static char* add_authors_risx(char** ptr_buffer, size_t* ptr_buffer_len, dbi_con
 	  return NULL;
 	}
 	  
-	if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+	if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	  free(entitize_buf);
 	  free_authorinfo(ptr_ainfo);
 	  return NULL;
@@ -724,7 +726,7 @@ static char* add_authors_risx(char** ptr_buffer, size_t* ptr_buffer_len, dbi_con
 	  return NULL;
 	}
       
-	if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+	if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	  free(entitize_buf);
 	  free_authorinfo(ptr_ainfo);
 	  return NULL;
@@ -747,7 +749,7 @@ static char* add_authors_risx(char** ptr_buffer, size_t* ptr_buffer_len, dbi_con
 	    return NULL;
 	  }
 	    
-	  if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	    free(entitize_buf);
 	    free_authorinfo(ptr_ainfo);
 	    return NULL;
@@ -770,7 +772,7 @@ static char* add_authors_risx(char** ptr_buffer, size_t* ptr_buffer_len, dbi_con
 	  return NULL;
 	}
 	  
-	if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+	if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	  free(entitize_buf);
 	  free_authorinfo(ptr_ainfo);
 	  return NULL;
@@ -887,6 +889,29 @@ static char* add_pubinfo_risx(char** ptr_buffer, size_t* ptr_buffer_len, dbi_con
       return NULL;
     }
   }
+  else if ((item = get_refdb_chapternum(ptr_rendinfo->dbires)) != NULL
+	   && *item) {
+    nhave_data = 1;
+    if (print_element_x(item, &buffer1, &buffer1_len, "issue", NULL, NULL, NULL, NULL, ptr_indent, ptr_rendinfo->ptr_clrequest->namespace) == NULL) {
+      free(buffer1);
+      return NULL;
+    }
+  }
+
+  /*----------------------------------------------------------------*/
+  /* conference title */
+  if (!strcmp(type, "CONF")) {
+    item = get_refdb_booktitle_copy(ptr_rendinfo->dbires);
+
+    if (item != NULL) {
+      if (print_element_x(item, &buffer1, &buffer1_len, "conftitle", NULL, NULL, NULL, NULL, ptr_indent, ptr_rendinfo->ptr_clrequest->namespace) == NULL) {
+	free(buffer1);
+	free((char*)item);
+	return NULL;
+      }
+      free((char*)item);
+    }
+  }
 
   /*----------------------------------------------------------------*/
   /* start page */
@@ -1184,14 +1209,6 @@ static char* add_pubinfo_risx(char** ptr_buffer, size_t* ptr_buffer_len, dbi_con
     }
   }
 
-  if ((item = get_refdb_chapternum(ptr_rendinfo->dbires)) != NULL
-      && *item) {
-    nhave_data = 1;
-    if (print_element_x(item, &buffer1, &buffer1_len, "issue", NULL, NULL, NULL, NULL, ptr_indent, ptr_rendinfo->ptr_clrequest->namespace) == NULL) {
-      free(buffer1);
-      return NULL;
-    }
-  }
 
   /*----------------------------------------------------------------*/
   /* URL, L1 through L4. Pubinfo links are not owned by a particular user */
@@ -1207,6 +1224,7 @@ static char* add_pubinfo_risx(char** ptr_buffer, size_t* ptr_buffer_len, dbi_con
     }
 
     while ((item = get_ulink(dbires)) != NULL) {
+      nhave_data = 1;
       if (i == 0) {
 	strcpy(ulink_type, "url");
       }
