@@ -13,8 +13,7 @@
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   along with this program; if not, see <http://www.gnu.org/licenses/>
 
   ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
 
@@ -248,7 +247,7 @@ int render_scrn(struct renderinfo* ptr_rendinfo) {
 
   /* fetch all authors */
   while (get_author_parts(dbires, &ainfo) != NULL) {
-    char role[70]; /* role is 64, and then some */
+    char role[70] = ""; /* role is 64, and then some */
 
     have_author++;
     if ((new_ref = mstrcat(*(ptr_rendinfo->ptr_ref), ainfo.name, ptr_rendinfo->ptr_ref_len, 0)) == NULL) {
@@ -264,14 +263,14 @@ int render_scrn(struct renderinfo* ptr_rendinfo) {
 	&& *(ainfo.role)
 	&& strcmp(ainfo.role, "author")) {
 /*       sprintf(role, "(%s)", ainfo.role); */
-      if ((new_ref = mstrcat(*(ptr_rendinfo->ptr_ref), role, ptr_rendinfo->ptr_ref_len, 0)) == NULL) {
-	clean_request(dbires);
-	LOG_PRINT(LOG_CRIT, get_status_msg(801));
-	return 801;
-      }
-      else {
-	*(ptr_rendinfo->ptr_ref) = new_ref;
-      }
+/*       if ((new_ref = mstrcat(*(ptr_rendinfo->ptr_ref), role, ptr_rendinfo->ptr_ref_len, 0)) == NULL) { */
+/* 	clean_request(dbires); */
+/* 	LOG_PRINT(LOG_CRIT, get_status_msg(801)); */
+/* 	return 801; */
+/*       } */
+/*       else { */
+/* 	*(ptr_rendinfo->ptr_ref) = new_ref; */
+/*       } */
     }
     else if (strcmp(ainfo.role, "author")){
       have_editor++;
@@ -682,6 +681,7 @@ int render_scrn(struct renderinfo* ptr_rendinfo) {
   /* URL, L1 through L4, DOI */
   if (strstr((ptr_rendinfo->ptr_biblio_info)->format_string, "UR") != NULL
       || strstr((ptr_rendinfo->ptr_biblio_info)->format_string, "LX") != NULL
+      || strstr((ptr_rendinfo->ptr_biblio_info)->format_string, "DOI") != NULL
       || strstr((ptr_rendinfo->ptr_biblio_info)->format_string, "ALL") != NULL) {
     int i;
     char link_tag[12];
