@@ -13,8 +13,7 @@
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   along with this program; if not, see <http://www.gnu.org/licenses/>
 
   ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
 
@@ -27,12 +26,12 @@
 #include "backend.h"
 #include "backend-teix.h"
 #include "strfncs.h"
-#include "dbfncs.h"
 #include "linklist.h"
+#include "refdbd.h"
+#include "dbfncs.h"
 #include "risdb.h"
 #include "authorinfo.h"
 #include "connect.h" /* for get_status_msg() */
-#include "refdbd.h"
 #include "xmlhelper.h"
 
 /* some globals */
@@ -543,7 +542,7 @@ static char* add_analytic_teix(struct renderinfo* ptr_rendinfo, int n_refdb_id,
       return NULL;
     }
 
-    if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+    if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
       free((char*)item);
       free(entitize_buf);
       return NULL;
@@ -660,7 +659,7 @@ static char* add_monogr_teix(struct renderinfo* ptr_rendinfo, int n_refdb_id, ch
 	  return NULL;
 	}
     
-	if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+	if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	  free(entitize_buf);
 	  return NULL;
 	}
@@ -695,7 +694,7 @@ static char* add_monogr_teix(struct renderinfo* ptr_rendinfo, int n_refdb_id, ch
       return NULL;
     }
 
-    if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+    if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
       free((char*)item);
       free(entitize_buf);
       return NULL;
@@ -724,7 +723,7 @@ static char* add_monogr_teix(struct renderinfo* ptr_rendinfo, int n_refdb_id, ch
 	return NULL;
       }
 
-      if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+      if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	free(entitize_buf);
 	return NULL;
       }
@@ -745,7 +744,7 @@ static char* add_monogr_teix(struct renderinfo* ptr_rendinfo, int n_refdb_id, ch
       return NULL;
     }
 
-    if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+    if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
       free(entitize_buf);
       return NULL;
     }
@@ -768,7 +767,7 @@ static char* add_monogr_teix(struct renderinfo* ptr_rendinfo, int n_refdb_id, ch
       return NULL;
     }
 
-    if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+    if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
       free(entitize_buf);
       return NULL;
     }
@@ -793,7 +792,7 @@ static char* add_monogr_teix(struct renderinfo* ptr_rendinfo, int n_refdb_id, ch
       return NULL;
     }
 
-    if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+    if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
       free(entitize_buf);
       return NULL;
     }
@@ -807,7 +806,7 @@ static char* add_monogr_teix(struct renderinfo* ptr_rendinfo, int n_refdb_id, ch
 	return NULL;
       }
 
-      if (sgml_entitize(&entitized_endpage, NULL) == NULL) {
+      if (sgml_entitize(&entitized_endpage, ptr_rendinfo->ref_format) == NULL) {
 	free(entitize_buf);
 	free(entitized_endpage);
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
@@ -866,7 +865,7 @@ static char* add_monogr_teix(struct renderinfo* ptr_rendinfo, int n_refdb_id, ch
 	return NULL;
       }
 
-      if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+      if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	free(entitize_buf);
 	return NULL;
       }
@@ -885,7 +884,7 @@ static char* add_monogr_teix(struct renderinfo* ptr_rendinfo, int n_refdb_id, ch
 	    return NULL;
 	  }
 
-	  if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	    free(entitize_buf);
 	    return NULL;
 	  }
@@ -997,7 +996,7 @@ static char* add_series_teix(struct renderinfo* ptr_rendinfo, int n_refdb_id, ch
       return NULL;
     }
 
-    if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+    if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
       free((char*)item);
       free(entitize_buf);
       return NULL;
@@ -1084,7 +1083,7 @@ static char* add_author_info_teix(struct renderinfo* ptr_rendinfo, int author_ty
 	  return NULL;
 	}
 
-	if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+	if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	  clean_request(dbires);
 	  free(entitize_buf);
 	  return NULL;
@@ -1125,7 +1124,7 @@ static char* add_author_info_teix(struct renderinfo* ptr_rendinfo, int author_ty
 	  return NULL;
 	}
 
-	if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+	if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	  clean_request(dbires);
 	  free(entitize_buf);
 	  return NULL;
@@ -1156,7 +1155,7 @@ static char* add_author_info_teix(struct renderinfo* ptr_rendinfo, int author_ty
 	    return NULL;
 	  }
 	  
-	  if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+	  if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	    clean_request(dbires);
 	    free(entitize_buf);
 	    return NULL;
@@ -1179,7 +1178,7 @@ static char* add_author_info_teix(struct renderinfo* ptr_rendinfo, int author_ty
 	  return NULL;
 	}
 
-	if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+	if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	  clean_request(dbires);
 	  free(entitize_buf);
 	  return NULL;
@@ -1200,7 +1199,7 @@ static char* add_author_info_teix(struct renderinfo* ptr_rendinfo, int author_ty
 	  return NULL;
 	}
 
-	if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+	if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
 	  clean_request(dbires);
 	  free(entitize_buf);
 	  return NULL;
@@ -1270,7 +1269,7 @@ static char* add_notes_teix(struct renderinfo* ptr_rendinfo, int n_refdb_id, cha
       return NULL;
     }
 
-    if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+    if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
       free((char*)item);
       free(entitize_buf);
       return NULL;
@@ -1324,7 +1323,7 @@ static char* add_abstract_teix(struct renderinfo* ptr_rendinfo, int n_refdb_id,
       return NULL;
     }
 
-    if (sgml_entitize(&entitize_buf, NULL) == NULL) {
+    if (sgml_entitize(&entitize_buf, ptr_rendinfo->ref_format) == NULL) {
       free((char*)item);
       free(entitize_buf);
       return NULL;
