@@ -14,8 +14,7 @@
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   along with this program; if not, see <http://www.gnu.org/licenses/>
 
    ++++++++++++++++++++++++*/
 
@@ -502,7 +501,7 @@ int process_bib(char* infile, int file) {
       return 1;
     }
     else {
-      printf(html_string);
+      printf("%s", html_string);
       free(html_string);
     }
   }
@@ -851,7 +850,7 @@ acknowledgement, bibdate, isbn, keywords, lccn, issn, coden, affiliation, classi
       return 1;
     }
     else {
-      printf(html_string);
+      printf("%s",html_string);
       free(html_string);
     }
   }
@@ -1890,7 +1889,7 @@ void log_print(int priority, char* string) {
     fprintf(stderr, "%s\n", string);
   }
   else if (n_log_dest == 1) { /* output via syslog */
-    syslog(priority, string);
+    syslog(priority, "%s", string);
   }
   else { /* output in user-defined logfile */
     time(&the_time);
