@@ -13,8 +13,7 @@
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   along with this program; if not, see <http://www.gnu.org/licenses/>
 
   ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
 
@@ -408,7 +407,7 @@ void notes_start_handler(void *ptr_data, const char *el, const char **ptr_attr)
 
 
 	/* search orphans in t_xnote */
-	result = remove_xnote_entries(ptr_andata->n_note_id, ptr_andata->conn, 4);
+	result = remove_xnote_entries(ptr_andata->n_note_id, 0 /* any link target */, ptr_andata->conn, 4);
 
 	if (result && result < 4) { /* 4 indicates no link found */
 	  if (result == 1) {
@@ -1566,6 +1565,10 @@ int insert_link(const char* type, const char* target, dbi_conn conn, unsigned lo
     sprintf(sql_command, "SELECT author_id from t_author WHERE author_name=%s", quoted_target);
     strcpy(xref_type, "AUTHOR");
   }
+  else if (!strcmp(my_type, "REFID")) {
+    sprintf(sql_command, "SELECT refdb_id from t_refdb WHERE refdb_id=%s", quoted_target);
+    strcpy(xref_type, "REFERENCE");
+  }
   else if (!strcmp(my_type, "REFERENCE")) {
     sprintf(sql_command, "SELECT refdb_id from t_refdb WHERE refdb_citekey=%s", quoted_target);
     strcpy(xref_type, "REFERENCE");
@@ -1603,7 +1606,7 @@ int insert_link(const char* type, const char* target, dbi_conn conn, unsigned lo
   }
 
   /* check for existing link */
-  sprintf(sql_command, "SELECT xnote_id FROM t_xnote WHERE note_id="ULLSPEC" AND xnote_type=\'%s\' AND xref_id="ULLSPEC, (unsigned long long)n_note_id, my_type, (unsigned long long)n_xref_id);
+  sprintf(sql_command, "SELECT xnote_id FROM t_xnote WHERE note_id="ULLSPEC" AND xnote_type=\'%s\' AND xref_id="ULLSPEC, (unsigned long long)n_note_id, xref_type, (unsigned long long)n_xref_id);
   LOG_PRINT(LOG_DEBUG, sql_command);
 
   free(my_type);
