@@ -13,8 +13,7 @@
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   along with this program; if not, see <http://www.gnu.org/licenses/>
 
   ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
 
@@ -52,6 +51,7 @@ extern char port_address[];
 extern char the_pager[];
 extern char username[];
 extern char passwd[];
+extern char no_encrypt[];
 extern const char cs_term[];
 
 /*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -133,8 +133,7 @@ int init_dialog(int n_sockfd, char* passwd, char* inbuffer) {
   /* read status */
   if ((cs_status = read_status(n_sockfd))) {
     cgi_header(CGI_PLAIN);
-    fprintf(errstream, get_status_msg(cs_status));
-    fprintf(errstream, "\n");
+    fprintf(errstream, "%s\n", get_status_msg(cs_status));
     return 1;
   }
     
@@ -153,14 +152,17 @@ int init_dialog(int n_sockfd, char* passwd, char* inbuffer) {
     return 1;
   }
 
-  if (enigma_encrypt(passwd, scrambled_passwd, inbuffer)) {
-    cgi_header(CGI_PLAIN);
-    fprintf(errstream, "password encryption error\n");
-    return 1;
+
+  /* todo: check for no_encrypt setting and skip encryption if requested */
+  if (*no_encrypt != 't') {
+    if (enigma_encrypt(passwd, scrambled_passwd, inbuffer)) {
+      cgi_header(CGI_PLAIN);
+      fprintf(errstream, "password encryption error\n");
+      return 1;
+    }
+
+    numberize_passwd(passwd, scrambled_passwd);
   }
-
-  numberize_passwd(passwd, scrambled_passwd);
-
 /*    strcpy(passwd, scrambled_passwd); */
 
   return 0;
@@ -217,7 +219,7 @@ int listvalue (char* arg, char* command, char* help_string, char* err_string, in
   if (!n_cgi) {
     if (strncmp(arg, "-h", 2) == 0) {
       cgi_header(CGI_PLAIN);
-      fprintf(errstream, help_string);
+      fprintf(errstream, "%s", help_string);
       free(slvals.outbuffer);
       return 0;
     }
@@ -311,8 +313,7 @@ int getsimplelist(struct simplelistvals* slvals, int n_with_summary) {
   numbyte = tiwrite(slvals->n_sockfd, slvals->outbuffer, TERM_YES);
   if (numbyte == -1) {
     cgi_header(CGI_PLAIN);
-    fprintf(errstream, get_status_msg(110));
-    fprintf(errstream, "\n");
+    fprintf(errstream, "%s\n", get_status_msg(110));
     return 1;
   }
 
@@ -324,8 +325,7 @@ int getsimplelist(struct simplelistvals* slvals, int n_with_summary) {
   if (cs_status != 0 /* success */
       && cs_status != 803) { /* partial success */
     cgi_header(CGI_PLAIN);
-    fprintf(errstream, get_status_msg(cs_status));
-    fprintf(errstream, "\n");
+    fprintf(errstream, "%s\n", get_status_msg(cs_status));
     if (n_with_summary != 2) {
       return 1;
     }
@@ -399,7 +399,7 @@ int getsimplelist(struct simplelistvals* slvals, int n_with_summary) {
       if (cs_status != 0 /* success */
 	  && cs_status != 803) { /* partial success */
 	cgi_header(CGI_PLAIN);
-	fprintf(errstream, get_status_msg(cs_status));
+	fprintf(errstream, "%s", get_status_msg(cs_status));
 	return 1;
       }
 
@@ -562,8 +562,7 @@ int send_xml_data(FILE *infp, FILE *pagerfp, FILE *errstream, int n_sockfd, size
 /*        fflush(stdout); */
     if (n_result < n_chunksize && !feof(infp)) {
       /* no more data available */
-      fprintf(errstream, get_status_msg(401));
-      fprintf(errstream, "\n");
+      fprintf(errstream, "%s\n", get_status_msg(401));
       send_status(n_sockfd, 401, TERM_NO);
       free(buffer);
       return 1;
@@ -591,8 +590,7 @@ int send_xml_data(FILE *infp, FILE *pagerfp, FILE *errstream, int n_sockfd, size
       /* PHASE 2 */
       /* wait for acknowledgement of database server */
       if ((cs_status = read_status(n_sockfd))) {
-	fprintf(errstream, get_status_msg(cs_status));
-	fprintf(errstream, "\n");
+	fprintf(errstream, "%s\n", get_status_msg(cs_status));
 	return 1;
       }
 
@@ -620,7 +618,7 @@ int send_xml_data(FILE *infp, FILE *pagerfp, FILE *errstream, int n_sockfd, size
 	  /*   	printf("phase4 server reply:%s<<\n", inbuffer); */
 	  if (numbyte == -1) {
 	    /* timeout while reading */
-	    fprintf(errstream, get_status_msg(109));
+	    fprintf(errstream, "%s", get_status_msg(109));
 	    return 3;
 	  }
 
@@ -708,8 +706,7 @@ int send_ris_data(FILE *infp, FILE *pagerfp, FILE *errstream, int n_sockfd, char
 
       if (n_result == 0) {
 	cgi_header(CGI_PLAIN);
-	fprintf(errstream, get_status_msg(401));
-	fprintf(errstream, "\n");
+	fprintf(errstream, "%s\n", get_status_msg(401));
 	send_status(n_sockfd, 401, TERM_NO);
 	return 1;
       }
@@ -739,8 +736,7 @@ int send_ris_data(FILE *infp, FILE *pagerfp, FILE *errstream, int n_sockfd, char
       /* PHASE 2 */
       /* wait for acknowledgement of database server */
       if ((cs_status = read_status(n_sockfd))) {
-	fprintf(errstream, get_status_msg(cs_status));
-	fprintf(errstream, "\n");
+	fprintf(errstream, "%s\n", get_status_msg(cs_status));
 	return 1;
       }
 
@@ -771,7 +767,7 @@ int send_ris_data(FILE *infp, FILE *pagerfp, FILE *errstream, int n_sockfd, char
 	  numbyte = tread(n_sockfd, inbuffer, OUTBUF_LEN);
 	  if (numbyte == -1) {
 	    cgi_header(CGI_PLAIN);
-	    fprintf(errstream, get_status_msg(109));
+	    fprintf(errstream, "%s", get_status_msg(109));
 	    return 3;
 	  }
 	  
@@ -842,8 +838,7 @@ size_t read_terminated_string(struct simplelistvals* ptr_slvals, FILE* pagerfp,
       }
 
       if (numbyte == -1) {
-	fprintf(stderr, get_status_msg(109));
-	fprintf(stderr, "\n");
+	fprintf(stderr, "%s\n", get_status_msg(109));
 	*ptr_error = 1;
 	return 0;
       }
