@@ -14,8 +14,7 @@
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   along with this program; if not, see <http://www.gnu.org/licenses/>
 
    ++++++++++++++++++++++++*/
 
@@ -96,7 +95,7 @@ COMMAND commands[] = {
 int n_done;
 
 /*+ this array will hold the user preferences +*/
-Prefs prefs[12] = {
+Prefs prefs[13] = {
   {"serverip", ""},
   {"port", ""},
   {"verbose", ""},
@@ -108,6 +107,7 @@ Prefs prefs[12] = {
   {"logdest", ""},
   {"loglevel", ""},
   {"refdblib", ""},
+  {"no_encrypt", ""},
   {"", ""}
 };
 
@@ -124,6 +124,7 @@ char log_dest[PREFS_BUF_LEN] = "2"; /*+ default log destination (0 = stderr, 1 =
 char log_level[PREFS_BUF_LEN] = "6"; /*+ default level up to which messages are logged (0 through 7). -1 means no logging +*/
 char refdblib[PREFS_BUF_LEN] = ""; /* path to shareable files */
 char confdir[_POSIX_PATH_MAX+1] = ""; /* path to the config files */
+char no_encrypt[PREFS_BUF_LEN] = ""; /* do not encrypt passwords if 't' */
 int main_argc = 0; /* save argc for commands in batch mode */
 char **main_argv = NULL; /* save argv for commands in batch mode */
 
@@ -222,6 +223,7 @@ int main (int argc, char** argv)
   prefs[8].varvalue = log_dest;
   prefs[9].varvalue = log_level;
   prefs[10].varvalue = refdblib;
+  prefs[11].varvalue = no_encrypt;
 
   /* a slimy hack to detect options before we run getopt */
   j = 2;
@@ -249,7 +251,7 @@ int main (int argc, char** argv)
   }
 
   /* read command line settings. These may override the config file settings */
-  while ((n_opt = getopt(argc, argv, "c:d:C:e:E:f:hH:i:l:L:o:O:p:qrRT:u:vVw:W:y:")) != -1) {
+  while ((n_opt = getopt(argc, argv, "c:d:C:e:E:f:hH:i:l:L:o:O:p:qrRT:u:vVw:W:xy:")) != -1) {
     switch (n_opt) {
     case 'c':
       strncpy(the_pager, optarg, PREFS_BUF_LEN);
@@ -270,7 +272,7 @@ int main (int argc, char** argv)
       break;
     case 'h':
       if (!n_batchmode) {
-	fprintf(stderr, "Usage: refdba [-c pager] [-C command] [-e logdest] [-h] [-i IP_address] [-l loglevel] [-L logfile] [-p port] [-q] [-T time] [-u name] [-v] [-V] [-w password] [-y confdir]\nOptions: -c command to run a pager\n         -C run command in batch mode\n         -e log destination (0=stderr;1=syslog;2=custom file)\n         -h prints this help\n         -i set server IP address to address\n         -l log level (0<=level<=7)\n         -L full path to custom log file\n         -p set server port to port\n         -q ignore init-file\n         -T set timeout to time seconds\n         -u set username\n         -v show version information\n         -V switch to verbose mode\n         -w password (use '*' to be asked interactively)\n         -y look for configuration files in confdir\n");
+	fprintf(stderr, "Usage: refdba [-c pager] [-C command] [-e logdest] [-h] [-i IP_address] [-l loglevel] [-L logfile] [-p port] [-q] [-T time] [-u name] [-v] [-V] [-w password] [-x] [-y confdir]\nOptions: -c command to run a pager\n         -C run command in batch mode\n         -e log destination (0=stderr;1=syslog;2=custom file)\n         -h prints this help\n         -i set server IP address to address\n         -l log level (0<=level<=7)\n         -L full path to custom log file\n         -p set server port to port\n         -q ignore init-file\n         -T set timeout to time seconds\n         -u set username\n         -v show version information\n         -V switch to verbose mode\n         -w password (use '*' to be asked interactively)\n         -x do not encrypt passwords\n         -y look for configuration files in confdir\n");
 	exit (0);
       }
       else {
@@ -322,6 +324,9 @@ int main (int argc, char** argv)
       strncpy(passwd, optarg, PREFS_BUF_LEN);
       passwd[PREFS_BUF_LEN-1] = '\0';
       break;
+    case 'x':
+      strcpy(no_encrypt, "t");
+      break;
     case 'y':
       /* do nothing, this option is used before getopt runs */
       break;
@@ -356,7 +361,7 @@ int main (int argc, char** argv)
       }
       break;
     case ':':
-      fprintf(stderr, "Usage: refdba [-c pager] [-C command] [-e logdest] [-h] [-i IP_address] [-l loglevel] [-L logfile] [-p port] [-q] [-T time] [-u name] [-v] [-V] [-w password] [-y confdir]\nOptions: -c command to run a pager\n         -C run command in batch mode\n         -e log destination (0=stderr;1=syslog;2=custom file)\n         -h prints this help\n         -i set server IP address to address\n         -l log level (0<=level<=7)\n         -L full path to custom log file\n         -p set server port to port\n         -q ignore init-file\n         -T set timeout to time seconds\n         -u set username\n         -v show version information\n         -V switch to verbose mode\n         -w password (use '*' to be asked interactively)\n         -y look for configuration files in confdir\n");
+      fprintf(stderr, "Usage: refdba [-c pager] [-C command] [-e logdest] [-h] [-i IP_address] [-l loglevel] [-L logfile] [-p port] [-q] [-T time] [-u name] [-v] [-V] [-w password] [-x] [-y confdir]\nOptions: -c command to run a pager\n         -C run command in batch mode\n         -e log destination (0=stderr;1=syslog;2=custom file)\n         -h prints this help\n         -i set server IP address to address\n         -l log level (0<=level<=7)\n         -L full path to custom log file\n         -p set server port to port\n         -q ignore init-file\n         -T set timeout to time seconds\n         -u set username\n         -v show version information\n         -V switch to verbose mode\n         -w password (use '*' to be asked interactively)\n         -x do not encrypt passwords\n         -y look for configuration files in confdir\n");
       exit (1);
       break;
     case '?':
@@ -990,7 +995,8 @@ static int adduser (int n_remove, char* arg)
 
 
   /* encrypt newuser passwd if we have one */
-  if (newuser_passwd[0]) {
+  if (newuser_passwd[0]
+      && *no_encrypt != 't') {
     if (enigma_encrypt(newuser_passwd, newuser_scrambled_passwd, srv_inbuffer)) {
       fprintf(stderr, "password encryption error\n");
       send_status(n_sockfd, 112, TERM_NO);
@@ -1033,16 +1039,14 @@ static int adduser (int n_remove, char* arg)
   numbyte = tiwrite(n_sockfd, outbuffer, TERM_YES);
   if (numbyte == -1) {
     delete_all_lilimem(&sentinel);
-    fprintf(stderr, get_status_msg(110));
-    fprintf(stderr, "\n");
+    fprintf(stderr, "%s\n", get_status_msg(110));
     close(n_sockfd);
     return 1;
   }
 
   if ((n_server_status = read_status(n_sockfd))) {
     delete_all_lilimem(&sentinel);
-    fprintf(stderr, get_status_msg(n_server_status));
-    fprintf(stderr, "\n");
+    fprintf(stderr, "%s\n", get_status_msg(n_server_status));
     close(n_sockfd);
     return 1;
   }
@@ -1136,8 +1140,7 @@ static int adduser (int n_remove, char* arg)
   /* read data */
   if ((n_server_status = read_status(n_sockfd))) {
     delete_all_lilimem(&sentinel);
-    fprintf(stderr, get_status_msg(n_server_status));
-    fprintf(stderr, "\n");
+    fprintf(stderr, "%s\n", get_status_msg(n_server_status));
     close(n_sockfd);
     return 1;
   }
@@ -1194,8 +1197,7 @@ static int adduser (int n_remove, char* arg)
   /* read summary */
   if ((n_server_status = read_status(n_sockfd))) {
     delete_all_lilimem(&sentinel);
-    fprintf(stderr, get_status_msg(n_server_status));
-    fprintf(stderr, "\n");
+    fprintf(stderr, "%s\n", get_status_msg(n_server_status));
     close(n_sockfd);
     return 1;
   }
@@ -1214,7 +1216,7 @@ static int adduser (int n_remove, char* arg)
 
   closepager(pagerfp);
 
-  fprintf(stderr, inbuffer);
+  fprintf(stderr, "%s", inbuffer);
 
   n_broken_pipe = 0;
   delete_all_lilimem(&sentinel);
@@ -1486,8 +1488,7 @@ static int addword (int n_remove, char* arg) {
 
   if ((n_server_status = read_status(n_sockfd))) {
     delete_all_lilimem(&sentinel);
-    fprintf(stderr, get_status_msg(n_server_status));
-    fprintf(stderr, "\n");
+    fprintf(stderr, "%s\n", get_status_msg(n_server_status));
     close(n_sockfd);
     return 1;
   }
@@ -1560,15 +1561,14 @@ static int addword (int n_remove, char* arg) {
   numbyte = tiwrite(n_sockfd, outbuffer, TERM_YES);
   if (numbyte == -1) {
     delete_all_lilimem(&sentinel);
-    fprintf(stderr, get_status_msg(110));
+    fprintf(stderr, "%s", get_status_msg(110));
     close(n_sockfd);
     return 1;
   }
 
   if ((n_server_status = read_status(n_sockfd))) {
     delete_all_lilimem(&sentinel);
-    fprintf(stderr, get_status_msg(n_server_status));
-    fprintf(stderr, "\n");
+    fprintf(stderr, "%s\n", get_status_msg(n_server_status));
     close(n_sockfd);
     return 1;
   }
@@ -1625,15 +1625,14 @@ static int addword (int n_remove, char* arg) {
 
   if ((n_server_status = read_status(n_sockfd))) {
     delete_all_lilimem(&sentinel);
-    fprintf(stderr, get_status_msg(n_server_status));
-    fprintf(stderr, "\n");
+    fprintf(stderr, "%s\n", get_status_msg(n_server_status));
     close(n_sockfd);
     return 1;
   }
 
   numbyte = tread(n_sockfd, inbuffer, OUTBUF_LEN);
   if (numbyte == -1) {
-    fprintf(stderr, get_status_msg(109));
+    fprintf(stderr, "%s", get_status_msg(109));
     delete_all_lilimem(&sentinel);
     close(n_sockfd);
     n_broken_pipe = 0;
@@ -1645,7 +1644,7 @@ static int addword (int n_remove, char* arg) {
 
   closepager(pagerfp);
 
-  fprintf(stderr, inbuffer);
+  fprintf(stderr, "%s", inbuffer);
 
   close(n_sockfd);
   return (0);
@@ -1882,8 +1881,7 @@ int com_addstyle (char* arg)
 
   /* check server status */
   if ((cs_status = read_status(n_sockfd))) {
-    fprintf(stderr, get_status_msg(cs_status));
-    fprintf(stderr, "\n");
+    fprintf(stderr, "%s\n", get_status_msg(cs_status));
     return 1;
   }
   
@@ -1975,7 +1973,7 @@ int com_addstyle (char* arg)
 	  /*   	printf("phase4 server reply:%s<<\n", inbuffer); */
 	  if (numbyte == -1) {
 	    /* timeout while reading */
-	    fprintf(stderr, get_status_msg(109));
+	    fprintf(stderr, "%s", get_status_msg(109));
 	    result = 1;
 	    goto cleanup;
 	  }
@@ -1997,8 +1995,7 @@ int com_addstyle (char* arg)
 /* 	goto cleanup; */
       }
       else {
-	fprintf(stderr, get_status_msg(cs_status));
-	fprintf(stderr, "\n");
+	fprintf(stderr, "%s\n", get_status_msg(cs_status));
 	result = 1;
 	goto cleanup;
       }
@@ -2450,7 +2447,7 @@ void log_print(int priority, const char* string) {
     fprintf(stderr, "%s\n", string);
   }
   else if (n_log_dest == 1) { /* output via syslog */
-    syslog(priority, string);
+    syslog(priority, "%s", string);
   }
   else { /* output in user-defined logfile */
     time(&the_time);
