@@ -13,8 +13,7 @@ markus@mhoenicka.de 6-5-00
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   along with this program; if not, see <http://www.gnu.org/licenses/>
 
    +++++++++++++++++++++++++*/
 
@@ -107,16 +106,6 @@ int child_confserv(struct CLIENT_REQUEST* ptr_clrequest, struct ADDRESULT* ptr_a
     return 2;
   }
 
-  ptr_addresult->msg_len = 512;
-  ptr_addresult->msg = malloc(ptr_addresult->msg_len);
-  if (ptr_addresult->msg == NULL) {
-    send_status(ptr_clrequest->fd, 801, TERM_NO);
-    LOG_PRINT(LOG_CRIT, get_status_msg(801));
-    return 1;
-  }
-
-  *(ptr_addresult->msg) = '\0';
-
   /* check our access rights */
   retval = is_refdb_admin(ptr_clrequest, ptr_addresult);
   if (!retval) { /* unauthorized attempt likely */
@@ -390,7 +379,7 @@ dbi_conn connect_to_db(struct CLIENT_REQUEST* ptr_clrequest, const char* special
   LOG_PRINT(LOG_DEBUG, ptr_clrequest->db_path);
   LOG_PRINT(LOG_DEBUG, ptr_clrequest->db_encoding);
 
-  conn = dbi_conn_new(ptr_clrequest->dbserver);
+  conn = my_dbi_conn_new(ptr_clrequest->dbserver, ptr_clrequest->inst);
 
   if (!conn) {
     LOG_PRINT(LOG_WARNING, "creating database connection structure failed");
@@ -570,15 +559,6 @@ int listdb(struct CLIENT_REQUEST* ptr_clrequest, int select, struct ADDRESULT* p
   dbi_conn conn;
   dbi_result dbires;
 
-  if ((ptr_addresult->msg = malloc((size_t)OUTBUF_LEN)) == NULL) {
-    /* out of memory */
-    LOG_PRINT(LOG_CRIT, get_status_msg(801));
-    send_status(ptr_clrequest->fd, 801, TERM_NO);
-    return 1;
-  }
-
-  *(ptr_addresult->msg) = '\0';
-    
   /* connect to the database */
   if ((conn = connect_to_db(ptr_clrequest, NULL, 0)) != NULL) {
     if (*(ptr_clrequest->argument)) {
@@ -762,15 +742,6 @@ int listuser(struct CLIENT_REQUEST* ptr_clrequest, struct ADDRESULT* ptr_addresu
   char* myarg;
   char* new_msg;
 
-  ptr_addresult->msg_len = 512;
-  if ((ptr_addresult->msg = malloc(ptr_addresult->msg_len)) == NULL) {
-    send_status(ptr_clrequest->fd, 801, TERM_NO);
-    LOG_PRINT(LOG_CRIT, get_status_msg(801));
-    return 1;
-  }
-
-  *(ptr_addresult->msg) = '\0';
-    
   /* connect to the database */
   if ((conn = connect_to_db(ptr_clrequest, ptr_clrequest->current_db, 0)) != NULL) {
     driver = dbi_conn_get_driver(conn);
@@ -950,14 +921,6 @@ int createdb(struct CLIENT_REQUEST* ptr_clrequest, struct ADDRESULT* ptr_addresu
   char* new_msg;
   char message[128];
 
-  if ((ptr_addresult->msg = malloc(512)) == NULL) {
-    send_status(ptr_clrequest->fd, 801, TERM_NO);
-    LOG_PRINT(LOG_CRIT, get_status_msg(801));
-    return 1;
-  }
-
-  *(ptr_addresult->msg) = '\0';
-
   /* loop over all filename arguments */
   for (; optind < ptr_clrequest->inargc; optind++) {
     result = real_createdb(ptr_clrequest, ptr_clrequest->inargv[optind], ptr_addresult);
@@ -1208,17 +1171,6 @@ int deletedb(struct CLIENT_REQUEST* ptr_clrequest, int optind, struct ADDRESULT*
     return 1;
   }
 
-  ptr_addresult->msg_len = 1024;
-  ptr_addresult->msg = malloc(ptr_addresult->msg_len);
-  if (ptr_addresult->msg == NULL) {
-    free(sql_command);
-    send_status(ptr_clrequest->fd, 801, TERM_NO);
-    LOG_PRINT(LOG_CRIT, get_status_msg(801));
-    return 1;
-  }
-
-  *(ptr_addresult->msg) = '\0';
-
   /* connect to main database */
   if ((conn = connect_to_db(ptr_clrequest, NULL, 0)) == NULL) {
     send_status(ptr_clrequest->fd, 202, TERM_NO);
@@ -1435,17 +1387,6 @@ int adduser(struct CLIENT_REQUEST* ptr_clrequest, char *user_host, char *newuser
     return 1;
   }
 
-  ptr_addresult->msg_len = 1024;
-  ptr_addresult->msg = malloc(ptr_addresult->msg_len);
-  if (ptr_addresult->msg == NULL) {
-    delete_all_lilimem(&sentinel);
-    send_status(ptr_clrequest->fd, 801, TERM_NO);
-    LOG_PRINT(LOG_CRIT, get_status_msg(801));
-    return 1;
-  }
-
-  *(ptr_addresult->msg) = '\0';
-
   /* connect to the main database */
   if ((conn = connect_to_db(ptr_clrequest, NULL, 0)) != NULL) {
     /* see what driver we use */
@@ -2001,17 +1942,6 @@ int addword(struct CLIENT_REQUEST* ptr_clrequest, int n_remove, struct ADDRESULT
     return 1;
   }
 
-  ptr_addresult->msg_len = 1024;
-  ptr_addresult->msg = malloc(ptr_addresult->msg_len);
-  if (ptr_addresult->msg == NULL) {
-    delete_all_lilimem(&sentinel);
-    send_status(ptr_clrequest->fd, 801, TERM_NO);
-    LOG_PRINT(LOG_CRIT, get_status_msg(801));
-    return 1;
-  }
-
-  *(ptr_addresult->msg) = '\0';
-
   /* connect to the database */
   if ((conn = connect_to_db(ptr_clrequest, NULL, 0)) != NULL) {
 
