@@ -14,8 +14,7 @@
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   along with this program; if not, see <http://www.gnu.org/licenses/>
 
    ++++++++++++++++++++++++*/
 
@@ -292,17 +291,6 @@ int deletenote(struct CLIENT_REQUEST* ptr_clrequest, struct ADDRESULT* ptr_addre
     return 801;
   }
 
-  ptr_addresult->msg = malloc(256); /* something to start with */
-
-  if (!ptr_addresult->msg) {
-    send_status(ptr_clrequest->fd, 801, TERM_NO);
-    LOG_PRINT(LOG_CRIT, get_status_msg(801));
-    return 801;
-  }
-
-  *(ptr_addresult->msg) = '\0';
-  ptr_addresult->msg_len = 256;
-
   /* send acknowledgement to client */
   send_status(ptr_clrequest->fd, 0, TERM_NO);
 
@@ -548,7 +536,7 @@ static int delete_note_by_id(unsigned long long idval, dbi_conn conn, struct CLI
 
 
   /* search orphans in t_xnote */
-  result = remove_xnote_entries(idval, conn, 4);
+  result = remove_xnote_entries(idval, 0 /* any link target */, conn, 4);
 
   if (result == 1 || result == 3) {
     /* send message to client, reuse sql_command */
@@ -2324,7 +2312,7 @@ int getnote(struct CLIENT_REQUEST* ptr_clrequest, struct bibinfo *ptr_biblio_inf
 	}
 	sql_command = my_sql_command_start;
 	sql_command_len = outlength;
-	result_len = (size_t)(my_sql_command - my_sql_command_start - 1);
+	result_len = (size_t)(my_sql_command - my_sql_command_start);
       }
       else { /* no conversion required */
 	result_len = strlen(sql_command);
@@ -2670,8 +2658,10 @@ int addlink(struct CLIENT_REQUEST* ptr_clrequest, char* set_owner, struct ADDRES
 
   while ((ptr_curr = get_next_liliform(ptr_curr)) != NULL) {
 
-    if (!strcmp(ptr_curr->name, ":ID:")
-	|| !strcmp(ptr_curr->name, ":CK:")) {
+    if (!strcmp(ptr_curr->name, ":ID:")) {
+      sprintf(my_type, "REFID");
+    }
+    else if (!strcmp(ptr_curr->name, ":CK:")) {
       sprintf(my_type, "REFERENCE");
     }
     else if (!strcmp(ptr_curr->name, ":KW:")) {
@@ -2811,7 +2801,7 @@ int addlink(struct CLIENT_REQUEST* ptr_clrequest, char* set_owner, struct ADDRES
 	dbi_result_free(dbires);
       } /* end if :ID: */
 
-      result = remove_xnote_entries(n_target_id, conn, mode);
+      result = remove_xnote_entries(n_id, n_target_id, conn, mode);
 
       /* todo: fix output */
 
