@@ -14,8 +14,7 @@
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   along with this program; if not, see <http://www.gnu.org/licenses/>
 
    ++++++++++++++++++++++++*/
 
@@ -169,7 +168,7 @@ int whichdb(struct CLIENT_REQUEST* ptr_clrequest) {
   }
 
   the_time = dbi_result_get_datetime(dbires, "meta_create_date");
-  if (dbi_conn_error_flag(conn) == 0) {
+  if (my_dbi_conn_error_flag(conn) == 0) {
     if (the_time) {
       strftime(create_date, 64, "%Y-%m-%d %H:%M:%S", gmtime(&the_time));
     }
@@ -182,7 +181,7 @@ int whichdb(struct CLIENT_REQUEST* ptr_clrequest) {
   }
 
   the_time = dbi_result_get_datetime(dbires, "meta_modify_date");
-  if (dbi_conn_error_flag(conn) == 0) {
+  if (my_dbi_conn_error_flag(conn) == 0) {
     if (the_time) {
       strftime(modify_date, 64, "%Y-%m-%d %H:%M:%S", gmtime(&the_time));
     }
@@ -1195,17 +1194,6 @@ int deleteref(struct CLIENT_REQUEST* ptr_clrequest, struct ADDRESULT* ptr_addres
     return 1;
   }
 
-  ptr_addresult->msg = malloc(256); /* something to start with */
-
-  if (!ptr_addresult->msg) {
-    send_status(ptr_clrequest->fd, 801, TERM_NO);
-    LOG_PRINT(LOG_CRIT, get_status_msg(801));
-    return 1;
-  }
-
-  *(ptr_addresult->msg) = '\0';
-  ptr_addresult->msg_len = 256;
-
   /* send acknowledgement to client */
   send_status(ptr_clrequest->fd, 0, TERM_NO);
 
@@ -1291,7 +1279,7 @@ int deleteref(struct CLIENT_REQUEST* ptr_clrequest, struct ADDRESULT* ptr_addres
 
   int delete_ref_by_id returns 0 if failed, 1 if successful
 
-  unsigned long long idval ID value of the note to be deleted
+  unsigned long long idval ID value of the reference to be deleted
 
   dbi_conn conn database connection
 
@@ -1377,7 +1365,6 @@ int delete_ref_by_id(unsigned long long idval, dbi_conn conn, struct CLIENT_REQU
   }
 
   if (dbi_result_get_numrows(dbires_user) > 0) {
-
     if (dbi_result_next_row(dbires_user) == 0) {
       dbi_result_free(dbires_user);
       my_dbi_conn_unlock(conn);
@@ -1527,7 +1514,7 @@ int delete_ref_by_id(unsigned long long idval, dbi_conn conn, struct CLIENT_REQU
   }
 
   /* remove orphans in t_xnote */
-  result = remove_xnote_entries(idval, conn, 0 /*ref*/);
+  result = remove_xnote_entries(0 /* any note */, idval, conn, 0 /*ref*/);
 
   if (result != 0 && result != 4) {
     /* send message to client, reuse sql_command */
@@ -1707,17 +1694,6 @@ int pickref(struct CLIENT_REQUEST* ptr_clrequest, int n_remove, struct ADDRESULT
     return 1;
   }
 
-  ptr_addresult->msg_len = 512;
-  ptr_addresult->msg = malloc(ptr_addresult->msg_len);
-  if (ptr_addresult->msg == NULL) {
-    free(sql_command);
-    send_status(ptr_clrequest->fd, 801, TERM_NO);
-    LOG_PRINT(LOG_CRIT, get_status_msg(801));
-    return 1;
-  }
-
-  *(ptr_addresult->msg) = '\0';
-
   n_bufsize = atoi(ptr_clrequest->argument);
 
   /* try to allocate the amount the client requested */
@@ -1944,8 +1920,13 @@ int pickref(struct CLIENT_REQUEST* ptr_clrequest, int n_remove, struct ADDRESULT
       numrows = dbi_result_get_numrows(dbires);
 
       if (!numrows) { /* list contains no references */
-	struct ADDRESULT dummy_addresult;
-	if (remove_personal_list(conn, quoted_listname, ptr_clrequest, &dummy_addresult)) {
+	struct ADDRESULT* p_dummy_addresult;
+	if ((p_dummy_addresult = new_addresult(512)) == NULL) {
+	    LOG_PRINT(LOG_CRIT, get_status_msg(801));
+	    return 801;
+	}
+
+	if (remove_personal_list(conn, quoted_listname, ptr_clrequest, p_dummy_addresult)) {
 	  /* error */
 	  sprintf(sql_command, "264:%s\n", quoted_listname);
 	  if ((new_msg = mstrcat(ptr_addresult->msg, sql_command, &(ptr_addresult->msg_len), 0)) == NULL) {
@@ -1966,6 +1947,7 @@ int pickref(struct CLIENT_REQUEST* ptr_clrequest, int n_remove, struct ADDRESULT
 	    ptr_addresult->msg = new_msg;
 	  }
 	}
+	free_addresult(p_dummy_addresult);
       }
       dbi_result_free(dbires);
     }
@@ -2114,15 +2096,20 @@ int pick_one_reference(dbi_conn conn, unsigned long long n_ref_id, unsigned long
   dbires = dbi_conn_query(conn, sql_command);
   if (!dbires) {
     free(quoted_listname);
+    LOG_PRINT(LOG_DEBUG, "dbires went to NULL");
     return 234;
   }
 
   if (dbi_result_next_row(dbires)) {
     /* note already exists, check user id */
     n_list_owner_id = my_dbi_result_get_idval(dbires, "note_user_id");
-    
+/*     sprintf(sql_command, "n_list_owner_id went to %lld", n_list_owner_id); */
+    LOG_PRINT(LOG_DEBUG, sql_command);
+
     if (n_list_owner_id != n_user_id) { /* we're not owner of this list */
       free(quoted_listname);
+      LOG_PRINT(LOG_DEBUG, "not owner of this list");
+
       sprintf(sql_command, "266:%s:%s\n", (*listname)?listname:full_listname, username);
       if ((new_msg = mstrcat(ptr_addresult->msg, sql_command, &(ptr_addresult->msg_len), 0)) == NULL) {
 	LOG_PRINT(LOG_CRIT, get_status_msg(801));
@@ -2137,10 +2124,15 @@ int pick_one_reference(dbi_conn conn, unsigned long long n_ref_id, unsigned long
 
     /* we own this list. retrieve ID */
     n_list_id = my_dbi_result_get_idval(dbires, "note_id");
+/*     sprintf(sql_command, "n_list_id went to %lld", n_list_id); */
+    LOG_PRINT(LOG_DEBUG, sql_command);
   }
   else {
     /* note does not yet exist. Create a new one */
-    n_list_id = create_personal_list(conn, (*listname)?listname:full_listname, n_user_id, username);
+    n_list_id = create_personal_list(conn, (*listname)?(char*)listname:full_listname, n_user_id, username);
+
+/*     sprintf(sql_command, "new n_list_id went to %lld", n_list_id); */
+    LOG_PRINT(LOG_DEBUG, sql_command);
 
     if (!n_list_id) {
       free(quoted_listname);
@@ -2366,7 +2358,7 @@ int dump_one_reference(dbi_conn conn, unsigned long long n_ref_id, unsigned long
        with ulinks as that code relies on xuser entries */
     retcode = remove_ulink_entries(n_ref_id, username, conn, 0 /* reference */);
 
-    retcode = remove_xuser_entries(n_ref_id, username, conn);
+    retcode = remove_xuser_entries(n_ref_id, (char*)username, conn);
   }
 
   dbi_result_free(dbires);
