@@ -13,8 +13,7 @@
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   along with this program; if not, see <http://www.gnu.org/licenses/>
 
    +++++++++++++++++++++++++*/
 
@@ -36,6 +35,7 @@
 extern int n_log_level;
 extern char refdblib[];
 extern char main_db[];
+extern dbi_inst Inst;
 
 /* prototypes of local functions */
 static short int dispatch_update_main_db(struct CLIENT_REQUEST* ptr_clrequest, dbi_conn conn, short int current_version, short int target_version);
@@ -101,7 +101,7 @@ int update_main_db(struct CLIENT_REQUEST* ptr_clrequest, int n_updatedb) {
       
     n_main_dbversion = dbi_result_get_short(dbires, "meta_dbversion");
 		
-    if (dbi_conn_error_flag(conn)) {
+    if (dbi_conn_error(conn, NULL)) {
       /* corrupt */
       LOG_PRINT(LOG_ERR, get_status_msg(203));
       dbi_result_free(dbires);
@@ -568,7 +568,7 @@ static int install_mysql_main_db(struct CLIENT_REQUEST* ptr_clrequest) {
   dbi_result dbires;
 
   /* get a connection to the MySQL system database */
-  if ((conn = dbi_conn_new("mysql")) == NULL) {
+  if ((conn = my_dbi_conn_new("mysql", ptr_clrequest->inst)) == NULL) {
     LOG_PRINT(LOG_ERR, "Cannot connect to database server. Installation of main database aborted");
     return 1;
   }
@@ -625,7 +625,7 @@ static int install_mysql_main_db(struct CLIENT_REQUEST* ptr_clrequest) {
   /* close connection and reconnect to new database */
   dbi_conn_close(conn);
 
-  if ((conn = dbi_conn_new("mysql")) == NULL) {
+  if ((conn = my_dbi_conn_new("mysql", ptr_clrequest->inst)) == NULL) {
     LOG_PRINT(LOG_ERR, "Cannot connect to database server. Installation of main database aborted");
     return 1;
   }
@@ -1101,7 +1101,7 @@ static int install_pgsql_main_db(struct CLIENT_REQUEST* ptr_clrequest) {
   snprintf(path, _POSIX_PATH_MAX, "%s/sql/refdb.%d.dump.pgsql", refdblib, MAIN_DB_VERSION);
 
   /* get a connection to template1 */
-  if ((conn = dbi_conn_new("pgsql")) == NULL) {
+  if ((conn = my_dbi_conn_new("pgsql", ptr_clrequest->inst)) == NULL) {
     LOG_PRINT(LOG_ERR, "Cannot connect to database server. Installation of main database aborted");
     return 1;
   }
@@ -1147,7 +1147,7 @@ static int install_pgsql_main_db(struct CLIENT_REQUEST* ptr_clrequest) {
   /* close connection and reconnect to new database */
   dbi_conn_close(conn);
 
-  if ((conn = dbi_conn_new("pgsql")) == NULL) {
+  if ((conn = my_dbi_conn_new("pgsql", ptr_clrequest->inst)) == NULL) {
     LOG_PRINT(LOG_ERR, "Cannot connect to database server. Installation of main database aborted");
     return 1;
   }
