@@ -13,8 +13,7 @@ markus@mhoenicka.de 2003-10-01
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   along with this program; if not, see <http://www.gnu.org/licenses/>
 
    +++++++++++++++++++++++++*/
 
@@ -386,7 +385,7 @@ int set_risdata_field(struct RISDATA* ptr_risdata, const char* fieldname, const
   dbi_driver driver ptr to database driver
 
   ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
-int set_risdata_dateinfo(struct RISDATA* ptr_risdata, int date_type, int year, const char* otherinfo, dbi_driver driver) {
+int set_risdata_dateinfo(struct RISDATA* ptr_risdata, int date_type, int year, const char* otherinfo, dbi_conn conn) {
   char* escape_buffer;
 
   if (!ptr_risdata) {
@@ -413,7 +412,7 @@ int set_risdata_dateinfo(struct RISDATA* ptr_risdata, int date_type, int year, c
   }
 
   /* escape any characters that the database server cannot digest */
-  if (dbi_driver_quote_string(driver, &escape_buffer) == 0) {
+  if (dbi_conn_quote_string(conn, &escape_buffer) == 0) {
     LOG_PRINT(LOG_WARNING, "out of memory");
     free(escape_buffer);
     return 1;
