@@ -15,8 +15,7 @@
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   along with this program; if not, see <http://www.gnu.org/licenses/>
 
   ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
 
@@ -34,6 +33,8 @@
 #include <errno.h>
 
 #include "strfncs.h"
+#include "outformats.h"
+#include "rtfhelper.h" /* for RTF treatment in sgml_entitize */
 
 /* Max integer that can be stored in a size_t variable */
 #ifndef SIZE_T_MAX
@@ -765,106 +766,6 @@ void remove_substring(char *buffer, size_t sublen) {
   }
 }
 
-/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-  sgml_entitize() replaces special characters with entities. The
-                  replacement is done according to an array of
-                  char/string pairs that has to be provided by the
-                  calling function.
-		  One source for entities and their Unicode equivalents:
-		  http://www.w3.org/TR/2000/WD-MathML2-20000211/bycodes.html
-
-  char* sgml_entitize returns a pointer to the converted string. This
-                  may be different from the original value of the
-		  passed pointer, so after calling this function only
-		  the returned value should be used. The function also
-		  modifies the value of the passed pointer to buffer.
-		  If the function is successful, the return value and
-		  the current value of the passed pointer will be
-                  identical. The return value is NULL if an error
-                  occurred. In this case, the current value of the
-		  passed pointer can still be used to access the 
-		  converted string as it was before the error.
-		  The buffer will be reallocated if needed, and the
-		  allocated length equals the length of the resulting
-		  string.
-
-  char** buffer pointer to a pointer to the string that will be
-                  entitized
-
-  struct charent* ptr_myents pointer to an array of character/string pairs
-                  which will be used for the replacements. The last
-                  element of the array must have a '0' (zero) as the
-		  character value as this is taken as a termination
-		  signal. You can also pass NULL here, then this fn
-                  will use a SGML default table.
-
-  ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
-char* sgml_entitize(char** buffer, struct charent* ptr_myents) {
-  int numents = 0;
-  int i = 0;
-  char *new_buffer;
-  char *token, *the_end;
-
-  struct charent* the_ents;
-  struct charent default_ents[7] = { /* default lookup table for entity replacements */
-    {"&", 1, "&amp;"},
-    {"<", 1, "&lt;"},
-    {">", 1, "&gt;"},
-    {{226, 128, 148, 0}, 3, "&mdash;"}, /* 0x2014 */
-    {{226, 128, 152, 0}, 3, "&lsquo;"}, /* 0x2018 */
-    {{226, 128, 153, 0}, 3, "&rsquo;"}, /* 0x2019 */
-    {"", 0, ""}
-  };
-
-  if (!ptr_myents) {
-    the_ents = default_ents;
-  }
-  else {
-    the_ents = ptr_myents;
-  }
-
-  while (the_ents[i].len != 0) {
-  
-    numents = count_the_flowers(*buffer, the_ents[i].letter, the_ents[i].len);
-/*     printf("numents for %s went to %d\n", the_ents[i].letter, numents); */
-    
-    if (numents > 0) {
-      if ((new_buffer = realloc(*buffer, strlen(*buffer) + ((strlen(the_ents[i].entity))*(numents+1)))) == NULL) {
-	return NULL;
-      }
-      else {
-	*buffer = new_buffer;
-      }
-      
-      token = strstr(*buffer, the_ents[i].letter);
-      the_end = &((*buffer)[strlen(*buffer)-1]);
-
-      while (token != NULL) {
-	char* next_amp;
-	char* next_sc;
-	char* next_sp;
-
-/*  	printf("token went to:%d<<letter went to %s\n", (int)*token, the_ents[i].letter); */
-	/* replace ampersand only if it does not start an entity */
-	/* get pointers to the next ampersand and semicolon, if any,
-	   and see which one is closer */
-	next_amp = strchr(token+1, (int)'&');
-	next_sc = strchr(token+1, (int)';');
-	next_sp = strchr(token+1, (int)' ');
-
-	if (*(the_ents[i].letter) != '&' || compare_ptr(&next_sc, &next_amp) != -1 || compare_ptr(&next_sp, &next_sc) != 1) {
-	  replace_char_string(token, the_ents[i].entity, the_ents[i].len);
-	  /* adjust the end using the number of chars added */
-	  the_end += strlen(the_ents[i].entity)-the_ents[i].len;
-	}
-	token = (token + the_ents[i].len > the_end) ? NULL:strstr(token+the_ents[i].len, the_ents[i].letter);
-      }
-    }
-    i++;
-  }
-  return *buffer;
-}
-
 /*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
   canonicalize_path(): converts a path to a canonical absolute path,
                        resolving all symbolic links and eliminating
