@@ -14,8 +14,7 @@
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   along with this program; if not, see <http://www.gnu.org/licenses/>
 
   ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
 
@@ -548,16 +547,21 @@ void end_handler(void *ptr_data, const char *el) {
 	     strcmp((ptr_asdata->ptr_first)->elname, "ASAME") == 0) {
       /* assemble column name */
       if (!strcmp(((ptr_asdata->ptr_first)->ptr_next)->elname, "AUTHORLIST")) {
-	strcpy(column_name, "Q");
-      }
-      else if (!strcmp(((ptr_asdata->ptr_first)->ptr_next)->elname, "EDITORLIST")) {
-	strcpy(column_name, "X");
-      }
-      else if (!strcmp(((ptr_asdata->ptr_first)->ptr_next)->elname, "SEDITORLIST")) {
-	strcpy(column_name, "Y");
-      }
-      else if (!strcmp(((ptr_asdata->ptr_first)->ptr_next)->elname, "ALLALIST")) {
-	strcpy(column_name, "Z");
+	/* check role attribute of ancestor */
+	ptr_attr = get_ancestor_attr(ptr_asdata->ptr_first, "AUTHORLIST", "ROLE");
+	if (ptr_attr && strcmp(ptr_attr, "PART") == 0) {
+	  strcpy(column_name, "Q"); /* AUTHORLIST */
+	}
+	else if (ptr_attr && strcmp(ptr_attr, "SERIES") == 0) {
+	  strcpy(column_name, "Y"); /* SEDITORLIST */
+	}
+	else if (ptr_attr && strcmp(ptr_attr, "ALL") == 0) {
+	  strcpy(column_name, "Z"); /* ALLALIST */
+	}
+	else {
+	  /* DTD uses this as default */
+	  strcpy(column_name, "X"); /* EDITORLIST */
+	}
       }
       else {
 	strcpy(column_name, ((ptr_asdata->ptr_first)->ptr_next)->elname);
@@ -1513,8 +1517,9 @@ void id_end_handler(void *ptr_data, const char *el) {
 	  
 	  /* see whether the style requests to use titles in place of
 	     missing authors. The style should have the ALTERNATETEXT
-	     attribute set to TITLEPART, TITLEPUB, TITLESERIES, or
-	     TITLEALL (the latter meaning the first available */
+	     attribute set to TITLEPART, TITLEPUB, TITLESERIES,
+	     TITLEALL (the latter meaning the first available), or to
+	     JOURNALNAME */
 	  if (!strcmp(my_dbi_conn_get_cap(ptr_gbdata->conn_refdb, "multiple_db"), "t")) {
 	    sprintf(sql_command, "SELECT QAEMPTY,XAEMPTY,QALTERNATETEXT,XALTERNATETEXT FROM %s.REFSTYLE INNER JOIN %s.CITSTYLE ON REFSTYLE.CITSTYLEID=CITSTYLE.ID WHERE REFSTYLE.PUBTYPE='%s' AND JOURNAL=%s", main_db, main_db, reftype, ptr_gbdata->quoted_journal);
 	  }
@@ -1707,7 +1712,50 @@ void id_end_handler(void *ptr_data, const char *el) {
 		    sql_command = new_sql_command;
 		  }
 		}
-		/* todo: make sure title is used */
+		/* use journalname as author */
+		else if (use_title_as_author == 5) {
+		  if (!strcmp(my_dbi_conn_get_cap(ptr_gbdata->conn, "multiple_db"), "t")) {
+		    item = get_periodical(ptr_gbdata->conn, periodical, database, 4, &errcode, 0, real_orig_id, NULL /* no frequency required */); 
+		  }
+		  else {
+		    item = get_periodical(conn_source, periodical, NULL, 4, &errcode, 0, real_orig_id, NULL /* no frequency required */); 
+		  }
+	  
+		  if (!item && errcode != 1) {
+		    LOG_PRINT(LOG_WARNING, "temp table periodical query failed");
+		    (*(ptr_gbdata->ptr_ndb_error))++;
+		  }
+		  else if (!errcode) {
+		    if (*periodical) {
+		      /* 	      printf("periodical went to:%s<<\n", periodical); */
+		      /* string is short enough, don't need mstrcat here */
+		      escape_buffer = strdup(item);
+
+		      if (!escape_buffer) {
+			LOG_PRINT(LOG_WARNING, "malloc failed");
+			(*(ptr_gbdata->ptr_nmem_error))++;
+		      }
+
+		      /* escape any characters that the database server cannot digest */
+		      if (dbi_conn_quote_string(ptr_gbdata->conn, &escape_buffer) == 0) {
+			LOG_PRINT(LOG_WARNING, "out of memory");
+			(*(ptr_gbdata->ptr_nmem_error))++;
+		      }
+
+		      /* 	      printf("escape_buffer went to:%s<<\n", escape_buffer); */
+		      escape_buffer[strlen(escape_buffer)-1] = '\0';
+		      if ((new_sql_command = mstrcat(sql_command, escape_buffer + 1, &sql_command_len, 0)) == NULL) {
+			(*(ptr_gbdata->ptr_nmem_error))++;
+		      }
+		      else {
+			sql_command = new_sql_command;
+		      }
+
+		      free(escape_buffer);
+		    }
+		  }
+		}
+		/* use title as author */
 		else if (use_title_as_author) {
 /*  		  printf("use qtitle %s\n", my_refdb_title);  */
 		  if (my_refdb_title) {
@@ -2102,7 +2150,7 @@ void idraw_end_handler(void *ptr_data, const char *el) {
       }
       else {
 	if (dbi_result_next_row(dbires)) {
-	  real_orig_citekey = dbi_result_get_string(dbires, "refdb_citekey");
+	  real_orig_citekey = (char*)dbi_result_get_string(dbires, "refdb_citekey");
 	  reftype = my_dbi_result_get_string_copy(dbires, "refdb_type");
 	}
 	dbi_result_free(dbires);
@@ -2278,6 +2326,9 @@ static int set_alternatetext(dbi_result dbires, char** ptr_aempty) {
       else if (!strcmp(qalternatetext, "TITLEALL")) {
 	use_title_as_author = 4; /* use first available title */
       }
+      else if (!strcmp(qalternatetext, "JOURNALNAME")) {
+	use_title_as_author = 5; /* use periodical name */
+      }
       else { /* AEMPTY */
 	use_title_as_author = 0;
 
@@ -2303,6 +2354,9 @@ static int set_alternatetext(dbi_result dbires, char** ptr_aempty) {
       else if (!strcmp(xalternatetext, "TITLEALL")) {
 	use_title_as_author = 4; /* use first available title */
       }
+      else if (!strcmp(xalternatetext, "JOURNALNAME")) {
+	use_title_as_author = 5; /* use periodical name */
+      }
       else { /* AEMPTY */
 	use_title_as_author = 0;
 	
