@@ -14,8 +14,7 @@
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   along with this program; if not, see <http://www.gnu.org/licenses/>
 
    ++++++++++++++++++++++++*/
 
@@ -36,6 +35,7 @@
 #include "xmlout.h"
 #include "strfncs.h"
 #include "dbfncs.h"
+#include "outformats.h"
 
 /* globals */
 extern int n_log_level;
@@ -45,6 +45,7 @@ static int iwrite_authorlist(struct CLIENT_REQUEST* ptr_clrequest, dbi_result db
 static int iwrite_authornames(struct CLIENT_REQUEST* ptr_clrequest, dbi_result dbires_ref, const char* role);
 static int iwrite_authorseps(struct CLIENT_REQUEST* ptr_clrequest, dbi_result dbires_ref, const char* role);
 static int iwrite_authortext(struct CLIENT_REQUEST* ptr_clrequest, dbi_result dbires_ref, const char* role);
+static int iwrite_editortext(struct CLIENT_REQUEST* ptr_clrequest, dbi_result dbires_ref, const char* role);
 static int iwrite_simple(struct CLIENT_REQUEST* ptr_clrequest, dbi_result dbires_ref, const char* elname);
 static int iwrite_twoatt(struct CLIENT_REQUEST* ptr_clrequest, dbi_result dbires_ref, const char* elname);
 static int iwrite_journalname(struct CLIENT_REQUEST* ptr_clrequest, dbi_result dbires_ref);
@@ -179,7 +180,7 @@ int iwrite_element(struct CLIENT_REQUEST* ptr_clrequest, const char* elname, Lil
 
   /* take care of entities */
   if ((entitize_buf = strdup(elvalue)) == NULL
-      || sgml_entitize(&entitize_buf, NULL) == NULL) {
+      || sgml_entitize(&entitize_buf, RISX) == NULL) {
       return 1;
   }
 
@@ -449,13 +450,13 @@ static int iwrite_authorlist(struct CLIENT_REQUEST* ptr_clrequest, dbi_result db
   sentinel.name[0] = '\0';
   sentinel.value = NULL;
 
-  if (!strcmp(role, "PRIMARY")) {
+  if (!strcmp(role, "PART")) {
     n_role = 0;
   }
-  else if (!strcmp(role, "SECONDARY")) {
+  else if (!strcmp(role, "PUB")) {
     n_role = 1;
   }
-  else if (!strcmp(role, "TERTIARY")) {
+  else if (!strcmp(role, "SERIES")) {
     n_role = 2;
   }
   else if (!strcmp(role, "ALL")) {
@@ -573,6 +574,7 @@ static int iwrite_authorlist(struct CLIENT_REQUEST* ptr_clrequest, dbi_result db
   iwrite_authorseps(ptr_clrequest, dbires_ref, role);
   iwrite_authornames(ptr_clrequest, dbires_ref, role);
   iwrite_authortext(ptr_clrequest, dbires_ref, role);
+  iwrite_editortext(ptr_clrequest, dbires_ref, role);
 
   /* end authorlist block */
   iwrite_elend(ptr_clrequest, "AUTHORLIST");
@@ -614,13 +616,13 @@ static int iwrite_authornames(struct CLIENT_REQUEST* ptr_clrequest, dbi_result d
   sentinel.name[0] = '\0';
   sentinel.value = NULL;
 
-  if (!strcmp(role, "PRIMARY")) {
+  if (!strcmp(role, "PART")) {
     n_role = 0;
   }
-  else if (!strcmp(role, "SECONDARY")) {
+  else if (!strcmp(role, "PUB")) {
     n_role = 1;
   }
-  else if (!strcmp(role, "TERTIARY")) {
+  else if (!strcmp(role, "SERIES")) {
     n_role = 2;
   }
   else if (!strcmp(role, "ALL")) {
@@ -730,13 +732,13 @@ static int iwrite_authorseps(struct CLIENT_REQUEST* ptr_clrequest, dbi_result db
   sentinel.name[0] = '\0';
   sentinel.value = NULL;
 
-  if (!strcmp(role, "PRIMARY")) {
+  if (!strcmp(role, "PART")) {
     n_role = 0;
   }
-  else if (!strcmp(role, "SECONDARY")) {
+  else if (!strcmp(role, "PUB")) {
     n_role = 1;
   }
-  else if (!strcmp(role, "TERTIARY")) {
+  else if (!strcmp(role, "SERIES")) {
     n_role = 2;
   }
   else if (!strcmp(role, "ALL")) {
@@ -805,13 +807,13 @@ static int iwrite_authortext(struct CLIENT_REQUEST* ptr_clrequest, dbi_result db
   sentinel.name[0] = '\0';
   sentinel.value = NULL;
 
-  if (!strcmp(role, "PRIMARY")) {
+  if (!strcmp(role, "PART")) {
     n_role = 0;
   }
-  else if (!strcmp(role, "SECONDARY")) {
+  else if (!strcmp(role, "PUB")) {
     n_role = 1;
   }
-  else if (!strcmp(role, "TERTIARY")) {
+  else if (!strcmp(role, "SERIES")) {
     n_role = 2;
   }
   else if (!strcmp(role, "ALL")) {
@@ -858,6 +860,92 @@ static int iwrite_authortext(struct CLIENT_REQUEST* ptr_clrequest, dbi_result db
   return 0;
 }
 
+/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+  iwrite_editortext() writes an authortext element (for editors) to a
+                      file descriptor.
+
+  static int iwrite_editortext 0 if fine, 1 if some error occurred
+
+  struct CLIENT_REQUEST* ptr_clrequest ptr to a structure with client info
+
+  dbi_result dbires_ref ptr to citstyle query result structure
+
+  const char* role ptr to string with the authorlist role
+
+  ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
+static int iwrite_editortext(struct CLIENT_REQUEST* ptr_clrequest, dbi_result dbires_ref, const char* role) {
+  char *singlepreceeding;
+  char *singlefollowing;
+  char *multiplepreceeding;
+  char *multiplefollowing;
+
+  char authorfields[4][4][34] = {
+    {"QTEXTEDTEXTSINGLEPRECEEDING", "QTEXTEDTEXTSINGLEFOLLOWING", "QTEXTEDTEXTMULTIPLEPRECEEDING", "QTEXTEDTEXTMULTIPLEFOLLOWING"},
+    {"XTEXTEDTEXTSINGLEPRECEEDING", "XTEXTEDTEXTSINGLEFOLLOWING", "XTEXTEDTEXTMULTIPLEPRECEEDING", "XTEXTEDTEXTMULTIPLEFOLLOWING"},
+    {"YTEXTEDTEXTSINGLEPRECEEDING", "YTEXTEDTEXTSINGLEFOLLOWING", "YTEXTEDTEXTMULTIPLEPRECEEDING", "YTEXTEDTEXTMULTIPLEFOLLOWING"},
+    {"ZTEXTEDTEXTSINGLEPRECEEDING", "ZTEXTEDTEXTSINGLEFOLLOWING", "ZTEXTEDTEXTMULTIPLEPRECEEDING", "ZTEXTEDTEXTMULTIPLEFOLLOWING"}
+  };
+
+  int n_role = 0;
+  Liliform sentinel;
+
+  sentinel.ptr_next = NULL;
+  sentinel.name[0] = '\0';
+  sentinel.value = NULL;
+
+  if (!strcmp(role, "PART")) {
+    n_role = 0;
+  }
+  else if (!strcmp(role, "PUB")) {
+    n_role = 1;
+  }
+  else if (!strcmp(role, "SERIES")) {
+    n_role = 2;
+  }
+  else if (!strcmp(role, "ALL")) {
+    n_role = 3;
+  }
+
+  /* get required strings */
+  singlepreceeding = (char*)my_dbi_result_get_string(dbires_ref, authorfields[n_role][0]);
+  singlefollowing = (char*)my_dbi_result_get_string(dbires_ref, authorfields[n_role][1]);
+  multiplepreceeding = (char*)my_dbi_result_get_string(dbires_ref, authorfields[n_role][2]);
+  multiplefollowing = (char*)my_dbi_result_get_string(dbires_ref, authorfields[n_role][3]);
+
+  if ((singlepreceeding && *singlepreceeding)
+      || (singlefollowing && *singlefollowing)
+      || (multiplepreceeding && *multiplepreceeding)
+      || (multiplefollowing && *multiplefollowing)) {
+    /* begin text block */
+    iwrite_elstart(ptr_clrequest, "TEXTED", &sentinel, 0);
+
+    if ((singlepreceeding && *singlepreceeding)
+      || (singlefollowing && *singlefollowing)) {
+      /* start textsingle block */
+      iwrite_elstart(ptr_clrequest, "TEXTSINGLE", &sentinel, 0);
+
+      iwrite_element(ptr_clrequest, "PRECEEDING", NULL, singlepreceeding);
+      iwrite_element(ptr_clrequest, "FOLLOWING", NULL, singlefollowing);
+      iwrite_elend(ptr_clrequest, "TEXTSINGLE");
+    }
+
+    if ((multiplepreceeding && *multiplepreceeding)
+      || (multiplefollowing && *multiplefollowing)) {
+      /* start textmultiple block */
+      iwrite_elstart(ptr_clrequest, "TEXTMULTIPLE", &sentinel, 0);
+
+      iwrite_element(ptr_clrequest, "PRECEEDING", NULL, multiplepreceeding);
+      iwrite_element(ptr_clrequest, "FOLLOWING", NULL, multiplefollowing);
+      iwrite_elend(ptr_clrequest, "TEXTMULTIPLE");
+    }
+
+    /* end authorseps block */
+    iwrite_elend(ptr_clrequest, "TEXTED");
+  }
+
+  return 0;
+}
+
 /*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
   iwrite_journalname() writes a journalname element to a file descriptor.
 
@@ -1163,13 +1251,13 @@ static int iwrite_title(struct CLIENT_REQUEST* ptr_clrequest, dbi_result dbires_
   sentinel.name[0] = '\0';
   sentinel.value = NULL;
 
-  if (!strcmp(role, "PRIMARY")) {
+  if (!strcmp(role, "PART")) {
     n_role = 0;
   }
-  else if (!strcmp(role, "SECONDARY")) {
+  else if (!strcmp(role, "PUB")) {
     n_role = 1;
   }
-  else if (!strcmp(role, "TERTIARY")) {
+  else if (!strcmp(role, "SERIES")) {
     n_role = 2;
   }
   else if (!strcmp(role, "ALL")) {
